<?php 

class FormModel {
	public $name;
	public $surname;
	public $phone;
	public $email;
	public $note;

	private $validationErrors = array();

	private $rules = array(
		array('name, surname, email', 'required', 'Field [field] cannot be blank'),
		array('phone', 'numeric', 'Field [field] must be numeric only'),
		array('email', 'email', 'Field [field] must be an valid e-mail addres'),
	);

	public $attributeLabels = array(
		'name' => 'Name',
		'surname' => 'Surname',
		'phone' => 'Phone no.',
		'email' => 'E-mail address',
		'note' => 'Drop a line...',
	);

	public function __set($name, $value) {
		if($name == 'attributes') {
			$this->validationErrors = array();
			foreach($value as $key=>$value) {
				$this->$key = $value;
			}
		}
	}

	public function attributeLabel($field) {
		return $this->attributeLabels[$field];
	}
	public function nameForAttribute($attr){
		return get_class($this).'['.$attr.']';
	}

	private function required($value) {
		if($value == '' || $value == null) return false;
		return true;
	}

	public function email($value) {
		$pattern = "/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$/";
		if(preg_match($pattern, $value)) {
			return true;
		} else {
			return false;
		}
	}

	public function numeric($value) {
		$value = str_replace(' ', '', $value);

		if(preg_match('/^[0-9]{1,14}$/', $value)) {
			return true;
		} else {
			return false;
		}
	}

	public function validate() {
		$err = false;

		foreach($this->rules as $value) {
			$fields = explode(',', $value[0]);
			$rule = $value[1];
			$message = $value[2];

			foreach($fields as $field) {
				$field = trim($field);

				if(!$this->$rule($this->$field)) {
					$this->validationErrors[$field] = str_replace('[field]', $this->attributeLabel($field), $message);
					$err=true;
				}
			}
		}

		return !$err;
	}

	public function getErrors() {
		return $this->validationErrors;
	}

	public function getError($field) {
		if($this->hasError($field)) {
			return $this->validationErrors[$field];
		} else {
			return '';
		}
	}

	public function hasError($field) {
		if(isset($this->validationErrors[$field]))
			return true;
		return false;
	}
}

?>