<?php

class YoliteThemeCustomize {
	public function init( $wp_customize ) {
		$this->registerControl('Color');

		/*
		 *  Upload logo image
		 */

		$wp_customize->add_section( 'theme_logo_section' , array(
			'title'			=> __('Logo','orange'),
			'priority'		=> 10,
			'description'	=> 'Set the site logo'
		) );

		$wp_customize->add_setting( 'uploaded_image' , array(
			'default'		=> '',
			'transport'		=> 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_upload', array(
			'label'			=> __( 'Logo', 'orange' ),
			'section'		=> 'theme_logo_section',
			'settings'		=> 'uploaded_image',
		) ) );

		/*
		 * Theme Color picker
		 */

		$wp_customize->add_section( 'color_theme_section' , array(
			'title'			=> __('Color theme','orange'),
			'priority'		=> 12,
			'description'	=> 'Change the base color theme'
			) );

		$wp_customize->add_setting( 'theme_color' , array(
			'default'		=> get_theme_mod('theme_color') || 'color-green.css',
			'transport'		=> 'refresh',
		) );

		$control = new yoliteCustomColorControl( $wp_customize, 'image_preview', array(
			'label'			=> __( 'Color Theme', 'orange' ),
			'section'		=> 'color_theme_section',
			'settings'		=> 'theme_color',
			) );

		$control->registerHooks();
		$wp_customize->add_control( $control );
	}

	public function registerControl($controlName) {
		$path = 'customizeThemeControls/yoliteCustom'.$controlName.'Control.php';
		include_once $path;
	}
	
	public function cleanGallery( $output, $attr  ){

		
		static $cleaner_gallery_instance = 0;
		$cleaner_gallery_instance++;

		if ( is_feed() )
			return $output;

		/* Default gallery settings. */
		$defaults = array(
			'order'       => 'ASC',
			'orderby'     => 'ID',
			'id'          => get_the_ID(),
			'link'        => '',
			'itemtag'     => 'figure',
			'icontag'     => '',
			'captiontag'  => '',
			'columns'     => 3,
			'size'        => 'thumbnail',
			'ids'         => '',
			'include'     => '',
			'exclude'     => '',
			'numberposts' => -1,
			'offset'      => ''
		);
		
		$attr = array_merge($defaults, $attr);
	
		extract( $attr );
		$id = intval( $id );

		/* Arguments for get_children(). */
		$children = array(
			'post_status'      => 'inherit',
			'post_type'        => 'attachment',
			'post_mime_type'   => 'image',
			'order'            => $order,
			'orderby'          => $orderby,
			'exclude'          => $exclude,
			'include'          => $include,
			'numberposts'      => $numberposts,
			'offset'           => $offset,
			'suppress_filters' => true
		);


		if (empty($include)) {
			$attachments = get_children(array_merge(array('post_parent' => $id ), $children));
		} else {
			$attachments = get_posts($children);
		}

		$attr['link'] = get_option('yolite_theme_gallery_link');

		if ($attr['link'] == '' || $attr['link'] == null) {
			$attr['link'] = 'full';
		}

		$size = get_option('yolite_theme_gallery_def_size');

		if ($size == '' || $size == null) {
			$size = 'thumbnail';
		}

		if ( empty( $attachments ) )
			return '<!-- No images. -->';
		
		$itemtag    = tag_escape( $itemtag );
		$icontag    = tag_escape( $icontag );
		$captiontag = tag_escape( $captiontag );
		$i = 0;

		$output = "<ul class='gallery'>";


		foreach ( $attachments as $attachment ) {
			$output .= "<li>";
				$lightbox = $attr['link'] == 'full' ? 'class="apply-lightbox"' : '' ;
				$output .= "<figure ".$lightbox.">";

					$image = ( ( isset( $attr['link'] ) && 'full' == $attr['link'] ) ? wp_get_attachment_link( $attachment->ID, $size, false, false ) : wp_get_attachment_link( $attachment->ID, $size, true, false ) );
					$output .= apply_filters( 'cleaner_gallery_image', $image, $attachment->ID, $attr, $cleaner_gallery_instance );
					
					if($attachment->post_excerpt != '') {
						$output .='<figcaption class="gallery-caption">'.$attachment->post_excerpt.'</figcaption>';
					}
				$output .= "</figure>";
				
			$output .= "</li>";

		}

		$output .= "</ul><!-- .gallery -->";
		return $output;
	}
}
?>
