<?php
include_once 'yoliteWebView.php';
include_once 'models/yoliteFormModel.php';
include_once 'admin/yoliteAdmin.php';
include_once 'admin/yoliteThemeCustomize.php';
include_once 'components/uploader/yoliteUploader.php';
include_once 'components/videoLinkExtractor/videoLinkExtractor.php';

Class YoliteBase {
	/*@var YoliteBase $instance*/
	public static $instance;
	/*@var YoliteWebView $render*/
	public static $renderEngine;

	public static $customizationEngine;

	public static $state;

	public static function init() {
		ob_start();
		$instance = new YoliteBase();
		self::$instance = $instance;
		
		$render = new YoliteWebView;
		self::$renderEngine = $render;
	}

	/**
	 * @return YoliteBase
	 */
	public static function instance() {
		return self::$instance;
	}

	static function categorySelect($name, $selected = null, $htmlOptions = array()) {
		$args = array(
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 0,
			'taxonomy'		=> 'category',
		);

		$categories = get_categories($args);
		self::$renderEngine->render('views/categorySelectView', array('yolitename' => $name, 'categories' => $categories, 'selectedValue' => $selected), $htmlOptions);

	}

	static function load($path){
		require $path;
	}
	
	static function postOptions() {
		if( ( !get_option('yolite_theme_post_share_facebook') && !get_option('yolite_theme_post_share_twitter') ) && ( is_single() || is_page() )){
		} else {
			self::$renderEngine->render('views/postOptions', array());
		}
	}

	static function advertBanner() {

		$banner = array('title' => get_option('yolite_banner_title'),
					'href' => get_option('yolite_banner_link'),
					'image' => get_option('yolite_banner_image')
					);

		if(	is_front_page() && get_option('yolite_banner_display_front') ||
			is_search() && get_option('yolite_banner_display_search') ||
			is_category() && get_option('yolite_banner_display_blog') ||
			is_single() && get_option('yolite_banner_display_single')){
			self::$renderEngine->render('views/banner', $banner);
		}
	}
	
	static public function renderOgTags() {

		$url = get_page_link();
		$type = 'article';
		$title = '';
		$image = '';
		$appId = '';
		$admins = '';

		global $post;
		if(is_single()) {

			$type = get_post_format( $post->ID );
			$type = $type == 'video' ? $type : 'article';

			if(has_post_thumbnail()){
				$imgs = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
				$image = $imgs[0];
			} else {
				$image = get_option( 'yolite_theme_og_default_image' );
			}

		} else {
			$image = get_option( 'yolite_theme_og_default_image' );
		}

		$title = get_option( 'yolite_theme_og_title' );

		$title = str_replace('%post_title%', $post->post_title, $title);
        $title = str_replace('%permalink%', get_permalink(), $title);
		$title = str_replace('%blog_name%', get_bloginfo('name'), $title);

		if($title == '') {
			$title = $post->post_title . ' | ' . get_bloginfo('name');
		}
		$appId = get_option( 'yolite_theme_og_app_id' );
		$admins = get_option( 'yolite_theme_og_admins' );

		self::$renderEngine->render('views/ogtags', array('url' => $url, 'type' => $type, 'title' => $title, 'image' => $image,
			'admins' => $admins, 'appId' => $appId));
	}

	public function complete() {
		if(!self::$state) {
			ob_clean();
			echo '<h1>One shall not simply remove the author of this theme!</h1>';
			echo '<h2><img src="data:image/gif;base64,iVBORw0KGgoAAAANSUhEUgAAAPIAAAA9CAIAAAAYtKOSAAAYI2lDQ1BJQ0MgUHJvZmlsZQAAWAmt
WXdUFMuz7plNLLBLzmnJSXLOOYPkrKQlZ5YcREBAgoKAIgKKgoqICqJESaKgCBcBBRUTQSSIigFB
AXmDV+/9vfPe++/NOTv7bfXX1dVVPT1dtQBw3vSOjAyF6QEIC4+h2Jnok1xc3Ui4lwACfAAN8IDb
mxwdqWdjYwn+z+vbJMJGrkdSu7r+T9r/3sDg6xdNBgCyQZp9fKPJYQi+CQCqjRxJiQEAs6tPKD4m
chcfQzAzBTEQwed3ccDfuG0X+/yNh39xHOwMEM40AFS03t6UAAAIK4icFEcOQPQQaQHAMob7BoUj
3UgI1iYHevsCwOmFcPaEhUXs4iMIFvP5Dz0B/4G9vX3+0entHfAP/nsuSE9kYMOg6MhQ78RfP/4/
b2GhsYi/fl28yJ02OsTeAvlmRfyWQPY2skcwO4ILAv3MLH/LL0bG6Nv9lncGxZg5IJgZ4TwOjDV1
/I0XY0Mc9RDMjci3QiIsdvmIn2D2cJ+91ghmRLAQOdoA8f3uWLByUqCD82+Opa+foRGCkVUEu1Ai
7P7wA6Pj7P/Ik5ICDfb+4Qd7m+/Gm4jw87wpCPplD1zmF2qyO64AIr8SGWOza+fuWCPhoXt/zwV+
408x3uXsyn/4Rf+a765tgTGBDqaIHLEZRR9DcdjlIHNEcfsHGZshGLENJRtIMf0j140M/bWmkb4o
B0qs3a4fhBDs7xfuuOvDXXmer7fhrm8Rn6AqgTHwBhTgB3xAOFgCJGAJDIDh7zsJkYcjMjKIAKHI
h0Ki+9OCeYsZw8xiJjDTmGd/ZEjP3zwQBHwR/Leu/+iPyO1BEniPaPUD0X9GQ3OitdEaaEvkrot8
5NGqaLU/bSMrrSt/8G9bA5C+Ur916/+2Pg7RuP2H5xmUQfmDf/fx+afH/7TJGLxBPBDwhyFbL7sk
u/Wn/78zxhphDbGmWGOsOCoHdQN1D3UbNYjqRLUCEqoH1YYaRnXt4t92/RnFG5HsemXXw9HAAvGi
H4j99Sv8z3j/zUux/zB+ayBKEJWAHdIrHIQgbUH/jOD0y+qg/6ElFmH4ICMGI1yLf+Lx2y60COJd
JbQ+WgvxM+JjNCuaE0ihFRGP66F1kBgoIdJ/o/jfZyMF/H95O+7XXELAW2QeYTF+CTHIWgIGEZGJ
lKCAwBiSHrJb+u0hmYWTpfeQ5GXlFMDu3rvLAeCL3a89FWJ9+K8sQg4Atd298tC/Mq8PALQGI9sN
478ykVYA6OQBGDxJjqXE/a0PvfuFAdSADnkqOAAvEARiiEfkgTLQALrACJgDa+AAXIEHsoYDQRhi
cTxIAekgG+SDY+AEKAdVoAZcAldBE2gFneA2GABDYBRMgOdgGsyDd2AVfAObEAThIALEBHFAfJAw
JAnJQ6qQNmQEWUJ2kCvkBQVA4VAslAIdgvKhYqgcOgfVQdehdug2NAiNQc+gGWgJ+gz9gFEwLcwM
88AisAysCuvBFrADvB8OgKPgJDgTLoDL4Gr4CtwC34aH4Al4Gn4Hr6EAigbFiuJHSaFUUQYoa5Qb
yh9FQaWi8lClqGrUNVQHshYfoaZRK6jvaCyaCU1CSyGRNEU7osnoKHQq+gi6HH0J3YK+i36EnkGv
on9iCBhujCRGHWOGccEEYOIx2ZhSzEVMM6YfeZ7nMd+wWCwrVhSrgqx2V2wwNhl7BHsa24DtxY5h
57BrOByOAyeJ08JZ47xxMbhs3CncFVwPbhw3j9ugoqHio5KnMqZyowqnyqAqpbpM1U01TrVAtYmn
xwvj1fHWeF98Ir4Qfx7fgX+In8dvUjNQi1JrUTtQB1OnU5dRX6Pup35B/YWGhkaARo3GliaIJo2m
jKaR5j7NDM13WkZaCVoD2n20sbQFtLW0vbTPaL8QCAQRgi7BjRBDKCDUEe4QXhE2iExEaaIZ0Zd4
kFhBbCGOEz/Q4emE6fToPOiS6ErpbtA9pFuhx9OL0BvQe9On0lfQt9M/oV9jYGKQY7BmCGM4wnCZ
YZBhkRHHKMJoxOjLmMlYw3iHcY4JxSTIZMBEZjrEdJ6pn2meGcssymzGHMycz3yVeYR5lYWRRZHF
iSWBpYKli2WaFcUqwmrGGspayNrEOsn6g42HTY/Njy2X7RrbONs6Oxe7Lrsfex57A/sE+w8OEocR
RwhHEUcrx0tONKcEpy1nPOcZzn7OFS5mLg0uMlceVxPXFDfMLcFtx53MXcM9zL3Gw8tjwhPJc4rn
Ds8KLyuvLm8w73Hebt4lPiY+bb4gvuN8PXzLJBaSHimUVEa6S1rl5+Y35Y/lP8c/wr8pICrgKJAh
0CDwUpBaUFXQX/C4YJ/gqhCfkJVQilC90JQwXlhVOFD4pPA94XURURFnkcMirSKLouyiZqJJovWi
L8QIYjpiUWLVYo/FseKq4iHip8VHJWAJJYlAiQqJh5KwpLJkkORpybE9mD1qe8L3VO95IkUrpScV
J1UvNSPNKm0pnSHdKv1BRkjGTaZI5p7MT1kl2VDZ87LP5RjlzOUy5DrkPstLyJPlK+QfKxAUjBUO
KrQpfFKUVPRTPKP4VIlJyUrpsFKf0rayijJF+ZrykoqQipdKpcoTVWZVG9UjqvfVMGr6agfVOtW+
qyurx6g3qX/UkNII0bissagpqumneV5zTktAy1vrnNa0NknbS/us9rQOv463TrXOrK6grq/uRd0F
PXG9YL0reh/0ZfUp+s366wbqBgcMeg1RhiaGeYYjRoxGjkblRq+MBYwDjOuNV02UTJJNek0xpham
RaZPzHjMyGZ1ZqvmKuYHzO9a0FrYW5RbzFpKWFIsO6xgK3OrEqsXe4X3hu9ttQbWZtYl1i9tRG2i
bG7ZYm1tbCts39rJ2aXY3bNnsve0v2z/zUHfodDhuaOYY6xjnxOd0z6nOqd1Z0PnYudpFxmXAy5D
rpyuQa5tbjg3J7eLbmvuRu4n3Of3Ke3L3je5X3R/wv5BD06PUI8uTzpPb88bXhgvZ6/LXlve1t7V
3ms+Zj6VPqtkA/JJ8jtfXd/jvkt+Wn7Ffgv+Wv7F/osBWgElAUuBOoGlgStBBkHlQZ+CTYOrgtdD
rENqQ3ZCnUMbwqjCvMLawxnDQ8LvRvBGJESMRUpGZkdOR6lHnYhapVhQLkZD0fuj22KYkUPucKxY
bFbsTJx2XEXcRrxT/I0EhoTwhOFEicTcxIUk46QLyehkcnJfCn9KesrMAb0D51KhVJ/UvoOCBzMP
zqeZpF1Kp04PSf8rQzajOOPrIedDHZk8mWmZc1kmWfXZxGxK9pPDGoerctA5QTkjuQq5p3J/5vnm
PciXzS/N3zpCPvLgqNzRsqM7Bf4FI4XKhWeOYY+FH5ss0im6VMxQnFQ8V2JV0nKcdDzv+NcTnicG
SxVLq05Sn4w9OV1mWdZ2SujUsVNb5YHlExX6FQ2V3JW5leunfU+Pn9E9c62Kpyq/6sfZoLNPz5mc
a6kWqS6twdbE1bw973T+3gXVC3UXOS/mX9yuDa+dvmR36W6dSl3dZe7LhfVwfWz90pV9V0avGl5t
uyZ17VwDa0N+I2iMbVy+7nV9ssmiqe+G6o1rN4VvVjYzNee1QC2JLautga3Tba5tY+3m7X0dGh3N
t6Rv1Xbyd1Z0sXQVdlN3Z3bv9CT1rPVG9q7cDrg91+fZ9/yOy53Hd23vjvRb9N8fMB64c0/vXs99
rfudg+qD7Q9UH7QOKQ+1DCsNN/+l9FfziPJIy0OVh22jaqMdY5pj3eM647cfGT4aeGz2eGhi78TY
pOPk0yf7nkw/9X26+Cz02aepuKnN52kvMC/yXtK/LH3F/ar6tfjrhmnl6a4Zw5nhWfvZ53PkuXdv
ot9szWe+JbwtXeBbqFuUX+xcMl4aXXZfnn8X+W5zJfs9w/vKD2Ifbn7U/Ti86rI6/4nyaefzkS8c
X2q/Kn7tW7NZe/Ut7Nvmet4Gx8al76rf7/1w/rGwGb+F2yrbFt/u+Gnx88VO2M5OpDfF+9dZAIXc
YX9/AD7XInmRKwBMowBQE//OjX4xkOMuhHAQjENOCubICWAOkkDe270wBxwDT6HMUHfQJujHmDAs
A7YPl0KljcfhX1K301TSFhJqiS/o6RksGHOZBlkYWPexXeFAc3pzdfGQeI/wbfD7CkwJ7RUeFJUR
KxB/J2m2p0rqm4yB7FG5UQWCor5StHKlSq/qtNq2BpumpJaatpGOnS5ZL1o/0+CkYb1Rj/EjkyXT
HXMWiz2WBlbue4Os42yybIvtquzrHVqRp37Iedzlmetrtzn3xX3v9y96vPAc8erxbvA5Qz7qm+Tn
728boBEoFEQM+hb8OmQgtC7saHhkhH2kShRn1BblVXRvTE1sVpx/vFmCZCJ14nLScHJjStmBzNT4
g1FplPSkjLxD5zK7sl4fxudo5kbm1eRPHqUu0CwMO3amaKR4+/ieE+6leSdbyqbLaSqUKj1P555p
qnp+Dl0tVeN0/uCFSxfHajfqSJct61OuNF391KDeWHj94w33mw9brFsft2t2xNyq63zRTdOj0Ot0
O6ov607R3dL+0oGiezn3Dw0efnB06Ohw1l8xI84PpR9ujvaOJY8rj3979ORx+0T55IEnnk/1nwlP
4afePx970fyy/NWB117ThjPis/Sz3+fevpmcH3x7e+HWYvtS+/KFdwUrce89Phh9lFylX137NPW5
+8u5r1lrgd8s1mU2mDbWv7/40btZvZW57ffTcEdgZweJPxZwIqfDBNCPnOgsoWPQa1gBOXt9QXmi
JpFT00tMJJaIbcX5UXFSTeErqQNo9Gm1CA7EQLo0+rMMtxmXmFlYDFkT2RrYP3JKc1G4O3lp+JxI
l/l3BPWE0oV7RLbEVMSDJU5LDu35LM0ioyBrKucuH6AQpZiodEA5SSVY1V3NUl1LQ1ZTQItFm0r7
h8573Rm9Cf0HBt2GN4xqjctMckzjzQLNXS1MLVWtRPeyWKOtv9rM2o7Z9do3OpxxzHGKdvZwMXNV
cONxx7p/QHb6Lo8azzyvCG8HH0UyLXnWt92v0N8/QDOQIfBt0K3gohC/UPUwurC58NaInEjXKElk
XYxEn42hxBrEscQtxLcnHEn0SJJNhpOfpDQcyE8NO+iYZpiunqF2SCvTNMslO/zw4ZwLuXfyZvJ/
HuUuUCt0OhZddKz4Ssng8bel8EnuMuVTtuVhFfmVV06Pnvl2VuCcTfWhmvbzny5K10Zdulm3Xq92
JeVqdwNo1Lt+qKn/JqbZpCWn9V47rsPoVkZnV9fXHpFe+9vJfWfu3Lo70b80sH4fPcj0gH9IZljr
L8sRt4eBo/Fj2eMnHlU/bpjonBx8Mvl0/tnX56gXzC+FX6m+tpwOmKmZXXojOu/2Nnvh8uK9pZnl
jRXie+EPOh/dV9M+jX5R+Fqy9mXdbuPmD/bNrK2Nn/G/4o8GDEAC7AVpoBc516tDMVArDMNW8Fl4
E+WBeoDWRLdgVDF9WBvsHC6ZiovqHv4oNZlGk5aL9idhljhE10x/gaGMsYAphzmLJZs1n62EvYqj
nrONq4u7i6ebt4evm3SLv1mgXvC0UL5wrMg+UV0xAXEg/lyiVTJ/j5MUSWpZulkmTdZCjlVuRr5e
IVZRRwmv9Ej5tEqgqqLqhlq3epaGhSaj5pRWtXawjrzOlu6AXpH+fgMJg3XDO0aFxu4moiafTbvN
8sydLPgt3lm2WKXttbRmtZ6xqbeNttOwh+0fOBQ7ujmRnBacr7nEumq4wW6D7oX77Pez7n/mUeG5
34vH66X3aZ/9ZG7ylG+Zn5M/k//DgPxAoyCArJe4ELmQldDaMJ9w7vAnESWRe6Ooom5TkqIVoldi
LsR6xLHFPYw/nKCTsJHYmBSUTEp+lnL8gEMqR+r8wba04+mJGf6H9mW6Zrln+x2OzcnKLc27mN9y
ZODoRMF84dciVDFTicBx2RPqpQYnzctsT7mW+1REVB48XXLmStXQ2Y/VwjWJ50cvitamXpq8LFWf
eeX5NbmGnMZXTco38m++blFoPdz2okPhVl7nbLdmT1nvtz6HO839ogPn70sN9g+F/CU0sjJ6b/z6
47rJxqe3p16+BK9lZ2rfZC/kLbd+oPuUs8a+0bzlvBv/v2tku+8ErDIAF+YAcDoHgK07ALWSAAhX
ICUcpMZiQwDAQQ3A+oUAenYKQCbX/nl/EIAoUlfwB4eRzHEQvIOIkBzkCCVBp6FO6Dm0heR3OrAP
nA1fhh/CX1FcKD1UIOoYqh01i6ZBMmwvJCNrQ7/BMGJ0MOGYc5gJLDVWD5uAbcKu4MRwAbha3BKV
NFUsVQ+eBu+Gv0INUbtQN9EQacJpxmlVac8SqAgUwiuiObGdToyunJ5An06/zhCB5CtkxtdMPkwL
zGHM31jSWYmsp9lk2O6wu7OvcRRxynE+4orn5uEe5TnMq88H+G6TsvitBDgEFgVvCRUJB4sYiwqL
0Yqtic9KjEve3dMhdUO6UaZBtkmuTb5XYUjxldInFbQqi5qgupSGnKasloQ2SYdRF9b9qPdcv8eg
2jDHKMLYxUTfVMaM15zOAmWxYblqtbx33nrWZsb2jd07+y8O2054ZzYXUVc1Nyt38r7k/Sc8GpH3
2HsfIlnB19XvoH9NQH/gXNB2CGMof5hEuHSEVKR4lACFNRof/SNmKY4z3iohM7En6WeK0YGS1Hdp
Vum3DilmtmebHZ7LPZzPf+RagW7hdFFRicsJrZNmp+Ir+s9wnSVWwzXfL3yu/VC3Ur9y9WPD2vXt
m1QtXG0yHYadrt1BvXF9qXfTBg7cj3sQOuw1kj/aNr48wf9k/7Oq529fyU2nz07MSy7kLC2smHy4
/In+S/La+w3/Hwvbkb/2DzogDWyROk456AFvIBqkGuAOZSIZ/xD0Ecnu1WEvOAduhJ+hUEjO7orK
Ql1HvUYTkF0lBF2B/gvJv+UwvphKJO50WEtsLvY+jhpnhSvGTVEJU1Go+vCs+FD8ALUgdQb1PI05
TQetJG0VgYVwhIglZtABunR6FH0OA5HhJKMAYwOTLtMEcxgLlqWaVY91li2bXYp9kiOdU5ZzmquE
25QHzdPHe4jPmERLmuSvFogWNBbiFdoQnhRpFT0rdlK8SKJAsmBPsVS59EWZZtn7cq/k1xVZlNSV
ySoFql1qHzWENT21KrSf6/Lq+eo3GGwaGRnnmwyZYcxVLHwss60u7r1tPWWzaoe2Z3WQcNR1cnWO
dil0veY24v5pP6uHlqe/V5F3t88HX0E/F//CgIHA7WDFkKDQM2FjEXCkfJQXpSD6VsxiHF28SoJX
Yn5SW/LCAbZUs4MH0prSlw8JZu7PKs9+msOW65p3Jv/NUamChMKBIvbiiJLhE7KlFWXEU7kVtJUn
zohW3TsXVEN7vumi2yV0XWO951X6a3caE5pkbiw217YGtUt1fO7s6M7otexjuzPX33gvZdB8iGN4
dMTx4dxY0iPexyOT+U/tp0ReQC9nXw/M1M8VzlMW7Je4lqtWRN9f/6i9OvLZ88vHtbR1uo1TP3g3
q7Y5fxb+ij8b0AORSOXoIdhBYu8PnYL6oS+wAGyH1HBa4RWkVuOCPO+DaBRSZUtCt6LXMEqYOEwX
FoO1xlZgl3EauGO4RSpDqvN4Knwk/gW1JXUvjQoSaX3aYYIrYZmYSsdC10hvTf+JoZRRm3GJ6TSz
PQuB5QFrLpslOyP7FMcFTgqXHjcT9zueAd7zfNmkEH4HAT1BeSFRYT4RLlFOMZK4pISapMUeb6kU
6XKZLtk38kQFTUWK0jXlj6pKaunq45piWpnab3Ut9VoNJA3PG/Ob1JiJmzdbGlo9tY60pbVrdHBH
ntcu1zh3xX0bHr1eR308fJX9aQOeBZWHmIUuhSdGbEXFUOZjbGJvxDMkUBIfJ6unnEulOZiQtpDh
cmg4Sz+7I0cxtyVf68hggWvhu6LUEobj1aUyJ9tPaZf3VGqebqnCnLU8d6L69XmJC/EX+y+x1Plf
7rhCvOp7rbOR5Xpk09BNMSTzed9m2956i7czu+tDj3Pv7T7JOyfu7gwE33s8qPugfpj1r+iRB6Nc
Y4HjVx4tTwhOOj/JeHrp2YOp+edbL+lf8b2WnFaaUZ/VntN9ozuv/VZ9QWVRbkliWeAd8d3SSvv7
+A9KH1Y+Xlh1/UT9qfOz/xf6L21f962Btepv+t9m1w9ucG+0f3f8vvrjyKboZt+Wx9bGdslPmZ+D
O7678Y/2V0DqkMgF0eoj5cdXOztfRJCkohiA7aKdnc3qnZ3tGiTZeAFAb+jf/7vskrFIrb4Skf/v
138BYVjB8HIyaoMAAAGcaVRYdFhNTDpjb20uYWRvYmUueG1wAAAAAAA8eDp4bXBtZXRhIHhtbG5z
Ong9ImFkb2JlOm5zOm1ldGEvIiB4OnhtcHRrPSJYTVAgQ29yZSA1LjEuMiI+CiAgIDxyZGY6UkRG
IHhtbG5zOnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+
CiAgICAgIDxyZGY6RGVzY3JpcHRpb24gcmRmOmFib3V0PSIiCiAgICAgICAgICAgIHhtbG5zOmV4
aWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20vZXhpZi8xLjAvIj4KICAgICAgICAgPGV4aWY6UGl4ZWxY
RGltZW5zaW9uPjI0MjwvZXhpZjpQaXhlbFhEaW1lbnNpb24+CiAgICAgICAgIDxleGlmOlBpeGVs
WURpbWVuc2lvbj42MTwvZXhpZjpQaXhlbFlEaW1lbnNpb24+CiAgICAgIDwvcmRmOkRlc2NyaXB0
aW9uPgogICA8L3JkZjpSREY+CjwveDp4bXBtZXRhPgqiGpE9AAAIk0lEQVR4Ae1dP2zbyhm/VxQi
UIRDQaOABRTkZA2Nh4Jd5AANgwLKUNkL31A6Q+NFGurXQcoie3Az2FpsDS96g7LEb0jUIVxsFYi0
2EDheAknuYMEFJAXBShMdOBDAWpJT5RISpYokhIpSsx3Acz7+/353Y/H704H5JsvX74gSIBAuBD4
WbjcAW8AgS4CQGvgQQgRAFqHcFLBJaA1cCCECACtQzip4BLQGjgQQgSA1iGcVHAJaA0cCCECQOsQ
Tiq4BLQGDoQQAaB1CCcVXAJaAwdCiADQOoSTCi4BrYEDIUQAaB3CSQWXgNbAgRAiALQO4aSCS0Br
4EAIEfi55z7Vz0/FpkwiheFSPBv1XP4CClwKl9uS+Pqy1Z2XeIrfCH5efLXHc1qrzdNi5bbLPXpV
4NmASahIp0/SRYqikCwzQqmU9cOgxXLZCnGlUauUpf68bFj1ml+9r/Z4HoQorZ/mB42tJpLlD+KY
0rKMkFROv6srtkPcd1gsl63sJ4hIr2nFqsd86321xwWtVUXV0kTv2zdlzCAtbTDkxK7zaSQ3j98Y
S3ThhXjnudqFc9lzD5dPoNMgpCF+9yx/3fWPPbgqbRIWnjYuy3oLxa45DOAUqVq7vGkhRD3kOI5l
rITrksc+rYUQ6wfHya0Xle4wufijxGdZL9+3qVwe6wJUeoaAM1q3q31OI5TLcJa0U+qFgtQ3jf4z
6+RrpzT2njyrGe6Uiyieu3jFu+OdnZAotytQld5npHxUS4ku5RvmjWamcHlUCNR4jYCTIEQ9f7nf
15s4TMasKKdW93Z0UqPdvU2rfgMuqOd7Oqdplu41XOdfvKsP9LHNOhGykjoS+oJu8x/bqq1QZx2m
cNmZYOg1GwL2tFYb4kudrbmU5VLdEF/sX+u20BneyYdebVa0Iexu6ZNYEj99yGhRsCS62dk5E4L3
jgnduor0Wc/O9JzG5ZkUwmCnCNjSWq0UCrowIW4R99bFPSNKwZ0PnUYRkd7mPME91FSsbCTj3cyK
vmnXau3+OBSy+ljn9XWlPvtyPa3Ldt5AuxcI2NG6fZnXl2pa4Eb3gHetjyfp3+3kzfCYzb19GrUM
v+/Z3NHK+RMRxwVqW3pd1FbvO7VXjxuVtmUyqGkrRFNCrCeEvnap1jIG96tcPGZ02YUm6DotAjZb
xpakHSBo0jcTa9pTVXCSP9frUqVYvJaHNFPJw+/52FDVhAIRSwl0unyLrgtbj4xvAhKynB6Xq+c7
W4VhFYa8zNuLbRzo2wvpj6CYnv242DFeG0PaxIx3Lk9UM2MjPn61lEAgWek7fdf5Ca8h+J9VIgin
q5KVhF59gPZMprUi9YLfrpnsunYOjUPtJ89MCg46Jhy82d1cdwUJmz09UL59WTGZm8i9yQ78tIul
CaWz3YdUx6BiJBKRb7a20oZqWyF6T5PMveBHr7d5euuyjbJpm9WW+OjbvJPRt8X0o+Kkjk//sv/7
6C8m9XDQ9r/2x8Mf/uGgI7K1J/P+atsi+rWSP5HWarsm6QPpx2u9JXTcq0wnMkc5Pka6onRPMrn5
tyr3vNFsyypBROmHzMqQELymUA8ovH4MLSHUA0a3S3vaCBnqO0XBY5ensGCuQ6o/HFbnqtBOWTcm
HWKF3QA0kdYImauauY0zv14UHRee81w8fo+LtlrvdSCZGMvcqxssjvFq9MdCOyGDAt3mvXfZrQX2
/SdEIPaDF7qH+ZF1bKYNrU05Oo8Ihv9wxnUiJEWS41Yxc8Ti5cyX1JVtS+EyEePP3m9MwYB7UPz3
X//8+9W/f0X1Ps33Gl0UFfk/v370pz/85pcuxozvGlnVot/xjRa1jmltjidWolGztDw5ud2c1til
cJmIMsy0DprjGIb57R/N4pLmpqD1vD2NjJ5iE4STH+bvGdqslPs1bMLlDuSeJI+LqtJuNVs43bQ+
40MmLJ0kSWqVWWWYGLPGRGddOD02dxnE2dDa/KhNwSMv/CceoNrlZWydHAgdCaTUJYQeu5PfqtX6
A9gE624D4k6R096YzdJl7cdiUZInD6GFTIpPcDNuYCbrCFnrRFoTJD7pxQTqJqmFwZ9/8PEgSknF
/XTPhqG/FDW6ig91GCoo9Y86q1GSXR1qm39BaZ2/zr/ULvU7UH5bLuyXC6h73JThY8MnRQ6Gf41d
vpn8P31JJ3z355Juoo4/VLmA1uyZZ0Z5xz8p9P0QPlSzwfmh1qvFnX09HBpyjGLZNYoi8WWAjiw3
mtLtuFU8kSvlHF24GRL9tRUmrtYIrSU2Eb4s2k2ydHvHrQTHhxlmRpHEPqcRSuaEAH1onf91x7g4
pnlEJ4QUn2TXmJWRU39VVT438VemXChfG97X8umG+lbcjhk1kBlFwOZOCLnGxfVB5fMbPbtcz/ZJ
uvdmYrOTqTEXW+boTsc8ZGSFw/cXV+JR9ikbG+U0tokgSGZ9Yzv76tPV2XEmYVgZ4Gtp2LDgGRta
I4J5vtu/CI0qr6TuNn3JknTyXUU3Wfh+d/7bA135wJNKlM4uStmnzMgKPdBpIEtEue2jq7M3gj4V
A22QHYOAHa3xXRB+j+oPvD29bI2RscBVinSi7w0Qih/sbgS90kUQvg12UT1i3R/bEdH1rHh1LNAR
hy/DAs+L36bZbBl76qVTPl3sbbgS7z8dMX4b5aV8HKBqdwA6+DR42X4V9RKHr0uW/WqN8WCfv0r2
YamdnLeWCiEcoGr3pIDTSzVtMxrriNb4wDp3dhinaZalO1LDvPgzo3IYDgj4g4CjIMQf1SAVEPAL
AYertV/qQS4g4AcCQGs/UAWZASMAtA54AkC9HwgArf1AFWQGjADQOuAJAPV+IAC09gNVkBkwAkDr
gCcA1PuBANDaD1RBZsAIAK0DngBQ7wcCQGs/UAWZASMAtA54AkC9HwgArf1AFWQGjADQOuAJAPV+
IAC09gNVkBkwAv8H5QzfnM8X240AAAAASUVORK5CYII="/></h2>';
			wp_die();
		} else {
			ob_end_flush();
		}
	}

	public function registerHooks() {
		add_action( 'admin_menu', array(new  yoliteAdmin(), 'adminMenu') );
		add_action( 'admin_enqueue_scripts', array($this, 'my_admin_enqueue') );
		add_action( 'customize_register', array( new YoliteThemeCustomize, 'init') );

		add_filter( 'post_gallery', array( new YoliteThemeCustomize, 'cleanGallery'), 10, 2 );

		add_action('wp_footer', array($this, 'complete'));
	}

	function my_admin_enqueue($hook_suffix) {
			
		if($hook_suffix == 'appearance_page_yolite-settings') {
			
			$uploader = new YoliteUploader();
			$uploader->registerHooks();
		}
	}

	/* video link extracter */
	static function extractLinksFrom($data) {
		$extractor = new VideoLinkExtractor;
		return $extractor->extract($data);
	}
}
?>
