<?php
/* yolitebase */
include_once('framework/yoliteBase.php');

YoliteBase::init();
YoliteBase::instance()->registerHooks();

function theme_author() {
	include_once 'framework/themeAuthor.php';
}

load_theme_textdomain('YoPress');

add_editor_style('custom-editor-style.css');
if ( ! isset( $content_width ) ) $content_width = 740;

/*
 * Custom styles & scripts
 */

function scripts_and_styles() {
	wp_register_style('grid', get_template_directory_uri() . '/css/grid.css', null, 1.0, 'screen');
	wp_register_style('grid-responsive', get_template_directory_uri() . '/css/grid.responsive.css', null, 1.0, 'screen');
	wp_register_style('normalize', get_template_directory_uri() . '/css/normalize.css', null, 1.0, 'screen');

	if (get_option('yolite_font_extended')) {
		wp_register_style('font-oswald', 'https://fonts.googleapis.com/css?family=Oswald&subset=latin,latin-ext', null, 1.0, 'screen');
		wp_register_style('font-pontano', 'https://fonts.googleapis.com/css?family=Pontano+Sans&subset=latin,latin-ext', null, 1.0, 'screen');
	} else {
		wp_register_style('font-oswald', 'https://fonts.googleapis.com/css?family=Oswald', null, 1.0, 'screen');
		wp_register_style('font-pontano', 'https://fonts.googleapis.com/css?family=Pontano+Sans', null, 1.0, 'screen');		
	}

	wp_register_style('main', get_template_directory_uri() . '/css/main.css', null, 1.0, 'screen');
	wp_register_style('core', get_template_directory_uri() . '/css/core.css', null, 1.0, 'screen');

	$color = 'color-orange.css';
	
	if (get_theme_mod('theme_color') != '') {
		$color = get_theme_mod('theme_color');
	}

	wp_register_style('color', get_template_directory_uri() . '/css/'.$color, null, 1.0, 'screen');	

	wp_enqueue_style(
			array(
				'grid',
				'grid-responsive',
				'normalize',
				'font-oswald',
				'font-pontano',
				'main',
				'core',
				'color'
			)
	);

	wp_register_script('modernizr', get_template_directory_uri() . '/js/vendor/modernizr-2.6.2.min.js', array('jquery'), 1.0, true);
	wp_register_script('plugins', get_template_directory_uri() . '/js/plugins.js', array('jquery'), 1.0, true);
	wp_register_script('slider-flex', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array('jquery'), 1.0, true);
	wp_register_script('slider-nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.pack.js', array('jquery'), 1.0, true);
	wp_register_script('cookie', get_template_directory_uri() . '/js/jquery.cookie.js', array('jquery'), 1.0, true);
	wp_register_script('easing', get_template_directory_uri() . '/js/jquery.easing-1.3.pack.js', array('jquery'), 1.0, true);
	wp_register_script('fancybox', get_template_directory_uri() . '/js/jquery.fancybox1.3.4.js', array('jquery'), 1.0, true);
	wp_register_script('player', get_template_directory_uri() . '/js/jquery.player.js', array('jquery'), 1.0, true);
	wp_register_script('main', get_template_directory_uri() . '/js/main.js', array('jquery'), 1.0, true);

	wp_enqueue_script('modernizr');
	wp_enqueue_script(
			array(
				'jquery',
				'plugins'
			)
	);

	if (get_option('yolite_theme_slider') == 'flexslider') {
		wp_enqueue_script('slider-flex');
	} else if (get_option('yolite_theme_slider') == 'nivo') {
		wp_enqueue_script('slider-nivo');
	}

	wp_enqueue_script(
			array(
				'cookie',
				'easing',
				'fancybox',
				'player',
				'main'
			)
	);
}

add_action('wp_enqueue_scripts', 'scripts_and_styles');

/* Tweaks */
remove_filter('term_description','wpautop');


global $excerptLength;
$excerptLength = get_option('yolite_theme_post_excerpt_length');

if($excerptLength == '' || $excerptLength == 0) {
	$excerptLength = 160;
}

function trim_excerpt( $content ) {
	global $excerptLength;
	$excerpt = explode(' ', $content);

	$returnString = '';

	foreach($excerpt as $word) {
		$returnString .= ' '.$word;
		if(strlen($returnString) > $excerptLength) break;
	}

	$returnString .= '...';
	return $returnString;
}

add_filter( 'the_excerpt', 'trim_excerpt' );

add_filter( 'wpcf7_form_class_attr', 'your_custom_form_class_attr');

function your_custom_form_class_attr( $class ) {
	$class .= ' generic-form';
	return $class;
}

/* shortcodes */
include_once 'shortcodes.php';

add_theme_support('menus');
add_theme_support('widgets');
add_theme_support('post-thumbnails');
add_theme_support('post-formats', array('video', 'image'));
add_theme_support( 'automatic-feed-links' );


		
set_post_thumbnail_size( 354, 216, true );

add_image_size('event_thumb', 165, 232, true);
add_image_size('gallery_thumb', 134, 134, true);
add_image_size('post_index_thumb', 340, 208, true);
add_image_size('slider_image', 1090, 384, true);

/* widgets */

include_once('widgets/gallery_widget.php');
include_once('widgets/video_widget.php');
include_once('widgets/event_poster_widget.php');
include_once('widgets/contact_note_widget.php');
include_once('widgets/social_hub_widget.php');
include_once('widgets/latest_twitter_tweets_widget.php');
include_once('widgets/our_team_widget.php');

/* siebars */

register_sidebar(array(
	'id' => 'right-sidebar',
	'name' => __('Main Right Sidebar', 'YoPress'),
	'description' => __('This sidebar is located on rigth side of page.', 'YoPress'),
	'before_widget' => '<li class="widget generic">',
	'after_widget' => '</li>',
	'before_title' => '<header><hgroup class="fancy-headers"><h1>',
	'after_title' => '</h1></hgroup></header>'
));

register_sidebar(array(
	'id' => 'left-footer',
	'name' => __('Left Footer Section', 'YoPress'),
	'description' => __('This sidebar is located on left side of the footer.', 'YoPress'),
	'before_widget' => '<li>',
	'after_widget' => '</li>',
));

register_sidebar(array(
	'id' => 'middle-footer',
	'name' => __('Middle Footer Section', 'YoPress'),
	'description' => __('This sidebar is located on midle side of the footer.', 'YoPress'),
	'before_widget' => '<li>',
	'after_widget' => '</li>',
));

register_sidebar(array(
	'id' => 'right-footer',
	'name' => __('Right Footer Section', 'YoPress'),
	'description' => __('This sidebar is located on right side of the footer.', 'YoPress'),
	'before_widget' => '<li>',
	'after_widget' => '</li>',
));

include_once('event_custom_post.php');

/*
 * Nav Menu
 */

if (function_exists('register_nav_menu')) {
	register_nav_menu('primary', __('Main menu', 'YoPress'));
    register_nav_menu('mobile', __('Menu visible on mobile', 'YoPress'));
}

function custom_excerpt_length($length) {
	return $length;
}

add_filter('excerpt_length', 'custom_excerpt_length', 20);

/* Custom comments markup */

function yopress_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	?>
	<?php $add_below = ''; ?>

	<li class="comment" id="comment-<?php comment_ID() ?>">
		<p class="comment-author">
			<?php echo get_avatar($comment, 48); ?>
			<cite><?php echo get_comment_author_link(); ?></cite>
			<br/><small class="comment-time"><strong><?php comment_date(); ?></strong> @<?php comment_time(); ?></small>
			<?php edit_comment_link(_e('Edit','YoPress')); ?>
		</p>
		<div class="commententry">
			<p>
				<?php if ($comment->comment_approved == '0') : ?>
					<em><?php _e('Your comment is awaiting moderation.', 'YoPress') ?></em>
					<br/>
				<?php endif; ?>
				<?php comment_text(); ?>
			</p>
			<p class="reply"><?php
			$reply = get_comment_reply_link(array_merge($args, array('reply_text' => 'Reply', 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'])));

			echo str_replace('comment-reply-link', 'btn btn-small comment-reply-link', $reply);
			?>
		</div>
	</li>
	<?php
}



	
/* Favicon */

add_action('wp_head', 'favicon');
function favicon() {
	if(get_option( 'yolite_favicon' ) != '') {
		echo '<link rel="shortcut icon" href="' . get_option( 'yolite_favicon' ) . '" type="image/x-icon" /><!-- Favi -->';
	}
}

if (is_admin()) {
	add_action('admin_head', 'favicon');
}

if(get_option('yolite_remove_wp_version')) {
	remove_action( 'wp_head', 'wp_generator');
}

/* Admin Bar Menu */

function yolite_admin_bar_render() {
	global $wp_admin_bar;
	$wp_admin_bar->add_menu( array(
		'parent' => false,
		'id' => 'yolite_settings', 
		'title' => __('YoPress','YoPress'), 
		'href' => admin_url( 'admin.php?page=yolite-settings'),
		'meta' => false
	));
}
add_action( 'wp_before_admin_bar_render', 'yolite_admin_bar_render' );



function theme_queue_js(){
if ( (!is_admin()) && is_singular() && comments_open() && get_option('thread_comments') )
  wp_enqueue_script( 'comment-reply' );
}
add_action('wp_print_scripts', 'theme_queue_js');

	

include_once 'custom-functions.php';
